@@ -35,7 +35,6 @@ use GooCanvas2;
 use GooCanvas2::CairoTypes;
 use Shutter::Screenshot::Main;
 use Shutter::Screenshot::History;
-use Shutter::Screenshot::ImageViewSelector;
 
 use Data::Dumper;
 our @ISA = qw(Shutter::Screenshot::Main);
@@ -60,12 +59,13 @@ sub new {
 	$self->{_init_y} = shift;
 	$self->{_init_w} = shift;
 	$self->{_init_h} = shift;
+	$self->{_confirmation_necessary} = shift;
 
 	$self->{_dpi_scale} = Gtk3::Window->new('toplevel')->get('scale-factor');
 
 	#view, selector, dragger
 	$self->{_view}     = Gtk3::ImageView->new;
-	$self->{_selector} =  Shutter::Screenshot::ImageViewSelector->new($self->{_view});
+	$self->{_selector} =  Gtk3::ImageView::Tool::Selector->new($self->{_view});
 	#$self->{_dragger}  = Gtk3::ImageView::Tool::Dragger->new($self->{_view});
 	$self->{_view}->set_interpolation('nearest');
 	$self->{_view}->set_tool($self->{_selector});
@@ -447,6 +447,25 @@ sub select_advanced {
 						$self->{_prop_active} = TRUE;
 						Gtk3::Gdk::keyboard_grab($self->{_prop_window}->get_window, 0, Gtk3::get_current_event_time());
 					}
+				} elsif ($event->button == 1) {
+					if (not $self->{_confirmation_necessary}) {
+						$self->{_select_window}->hide;
+						$self->{_zoom_window}->hide;
+						$self->{_prop_window}->hide;
+
+						#A short timeout to give the server a chance to
+						#redraw the area
+						Glib::Timeout->add(
+							$self->{_hide_time},
+							sub {
+								Gtk3->main_quit;
+								return FALSE;
+							});
+						Gtk3->main();
+
+						$output = $self->take_screenshot($s, $clean_pixbuf);
+						$self->quit;
+					}
 				}
 
 				#handle motion-notify
